@@ -350,6 +350,12 @@ export const ReferenceDataRelation = yup.object().shape({
   type: yup.string().oneOf(Object.values(REFERENCE_DATA_RELATION_TYPES)),
 });
 
+export const UserFacility = yup.object().shape({
+  // id is auto generated by db, so don't require it on import
+  facilityId: yup.string().required(),
+  userId: yup.string().required(),
+});
+
 export const InvoiceProduct = yup.object().shape({
   name: yup.string().required(),
   price: yup.number().required(),
