@@ -1,5 +1,6 @@
 import config from 'config';
 import { splitIds } from './utilities';
+import { selectFacilityIds } from '../utils/configSelectors';
 
 export const FACILITIES = splitIds(`
   Balwyn
@@ -18,14 +19,18 @@ export const FACILITIES = splitIds(`
 export const seedFacilities = async models => {
   const facilities = FACILITIES.map(d => ({ ...d, code: d.name }));
 
-  // ensure that whatever our configured serverFacilityId is has an entry as well
+  // ensure that all our configured serverFacilityIds have an entry as well
   // otherwise a bunch of tests will break
-  const { serverFacilityId } = config;
-  if (serverFacilityId && !facilities.some(x => x.id === serverFacilityId)) {
-    facilities.push({
-      id: serverFacilityId,
-      name: serverFacilityId,
-      code: serverFacilityId,
+  const serverFacilityIds = selectFacilityIds(config);
+  if (serverFacilityIds) {
+    serverFacilityIds.forEach(facilityId => {
+      if (!facilities.some(x => x.id === facilityId)) {
+        facilities.push({
+          id: facilityId,
+          name: facilityId,
+          code: facilityId,
+        });
+      }
     });
   }
 
