@@ -1,6 +1,7 @@
 /** @typedef {import('sequelize').QueryInterface} QueryInterface */
 import config from 'config';
 import { Op } from 'sequelize';
+import { selectFacilityIds } from '../utils/configSelectors';
 
 const DEFAULT_SETTINGS = {
   'vaccinationReminder.due': JSON.stringify([7, 1, -7]),
@@ -10,7 +11,8 @@ const DEFAULT_SETTINGS = {
  * @param {QueryInterface} query
  */
 export async function up(query) {
-  if (config?.serverFacilityId) return;
+  const isFacilityServer = !!selectFacilityIds(config);
+  if (isFacilityServer) return;
   await query.bulkInsert(
     'settings',
     Object.entries(DEFAULT_SETTINGS).map(([key, value]) => ({
@@ -24,7 +26,8 @@ export async function up(query) {
  * @param {QueryInterface} query
  */
 export async function down(query) {
-  if (config?.serverFacilityId) return;
+  const isFacilityServer = !!selectFacilityIds(config);
+  if (isFacilityServer) return;
   await query.bulkDelete('settings', {
     key: {
       [Op.in]: Object.keys(DEFAULT_SETTINGS),
